.. role:: hidden
    :class: hidden-section

ax.benchmark
===================================

.. automodule:: ax.benchmark
.. currentmodule:: ax.benchmark

Benchmark
----------------

Benchmark Problem
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.benchmark_problem
    :members:
    :undoc-members:
    :show-inheritance:


Benchmark Result
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.benchmark_result
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark
~~~~~~~~~

.. automodule:: ax.benchmark.benchmark
    :members:
    :undoc-members:
    :show-inheritance:


Benchmark Utilities
~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.utils
    :members:
    :undoc-members:
    :show-inheritance:


BoTorch Methods
~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.botorch_methods
    :members:
    :undoc-members:
    :show-inheritance:


Modular Botorch Benchmarking
------------------------------

Standard Methods
~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.botorch_modular.standard_methods
    :members:
    :undoc-members:
    :show-inheritance:

Standard Problems
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.botorch_modular.standard_problems
    :members:
    :undoc-members:
    :show-inheritance:
